"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onCall = onCall;
require("reflect-metadata");
const internal_methods_1 = require("../internal-methods");
const types_1 = require("../types");
/**
 * Decorator that adds the class method to the Cloud Functions list triggered as a callable
 * function.
 *
 * @example
 * import { onCall } from 'firebase-triggers';
 * import { CallableRequest } from 'firebase-functions/lib/common/providers/https';
 *
 * class TodoCtrl {
 *     \@onCall()
 *     add(event: CallableRequest) {
 *         console.log('Add new todo', event.data);
 *     }
 * }
 */
function onCall(options = {}) {
    return (target, key) => {
        const firebaseFunction = {
            className: (0, internal_methods_1.getClassName)(target),
            methodName: key,
            method: (0, internal_methods_1.getClassMethod)(target, key),
            trigger: types_1.FirebaseTriggerType.CALLABLE,
            options,
        };
        (0, internal_methods_1.addFirebaseFunction)(firebaseFunction);
        Reflect.defineMetadata('onCall', options, target, key);
    };
}
//# sourceMappingURL=callable.js.map