import { BlockingOptions } from 'firebase-functions/v2/identity';
/**
 * Decorator that adds the class method to the Cloud Functions list triggered when creating a new
 * user in Firebase Authentication.
 *
 * @example
 * import { onFirebaseUserCreate } from 'firebase-triggers';
 * import { AuthBlockingEvent } from 'firebase-functions/v2/identity';
 * import { EventContext } from 'firebase-functions';
 *
 * class UserCtrl {
 *     \@onFirebaseUserCreate()
 *     onCreate(event: AuthBlockingEvent) {
 *         console.log(`${event.data.displayName} joined us`);
 *     }
 * }
 */
export declare function onFirebaseUserCreate(options?: BlockingOptions): (target: any, key: string) => void;
