"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onFirebaseUserCreate = onFirebaseUserCreate;
const internal_methods_1 = require("../internal-methods");
const types_1 = require("../types");
/**
 * Decorator that adds the class method to the Cloud Functions list triggered when creating a new
 * user in Firebase Authentication.
 *
 * @example
 * import { onFirebaseUserCreate } from 'firebase-triggers';
 * import { AuthBlockingEvent } from 'firebase-functions/v2/identity';
 * import { EventContext } from 'firebase-functions';
 *
 * class UserCtrl {
 *     \@onFirebaseUserCreate()
 *     onCreate(event: AuthBlockingEvent) {
 *         console.log(`${event.data.displayName} joined us`);
 *     }
 * }
 */
function onFirebaseUserCreate(options = {}) {
    return (target, key) => {
        const firebaseFunction = {
            className: (0, internal_methods_1.getClassName)(target),
            methodName: key,
            method: (0, internal_methods_1.getClassMethod)(target, key),
            trigger: types_1.FirebaseTriggerType.USER_CREATE,
            options,
        };
        (0, internal_methods_1.addFirebaseFunction)(firebaseFunction);
        Reflect.defineMetadata('onFirebaseUserCreate', options, target, key);
    };
}
//# sourceMappingURL=firebase-user-create.js.map