"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onFirebaseUserDelete = onFirebaseUserDelete;
const internal_methods_1 = require("../internal-methods");
const types_1 = require("../types");
/**
 * Decorator that adds the method to the Cloud Functions list that is triggered when removing a
 * user from Firebase Authentication.
 *
 * @example
 * import { onFirebaseUserDelete } from 'firebase-triggers';
 * import { UserRecord } from 'firebase-functions/auth';
 * import { EventContext } from 'firebase-functions';
 *
 * class UserCtrl {
 *     \@onFirebaseUserDelete()
 *     onDelete(user: UserRecord, context: EventContext) {
 *         console.log(`${user.displayName} left us`);
 *     }
 * }
 */
function onFirebaseUserDelete(options = {}) {
    return (target, key) => {
        const firebaseFunction = {
            className: (0, internal_methods_1.getClassName)(target),
            methodName: key,
            method: (0, internal_methods_1.getClassMethod)(target, key),
            trigger: types_1.FirebaseTriggerType.USER_DELETE,
            options,
        };
        (0, internal_methods_1.addFirebaseFunction)(firebaseFunction);
        Reflect.defineMetadata('onFirebaseUserDelete', options, target, key);
    };
}
//# sourceMappingURL=firebase-user-delete.js.map