import { ScheduleOptions } from 'firebase-functions/v2/scheduler';
/**
 * Decorator that adds the method to the list of Cloud Functions triggered when a publication is
 * made via PubSub triggered via Cron.
 *
 * @param schedule Cron time interval (ex: '5 11 * * *' ou 'every 5 minutes')
 * @example
 * import { ScheduledEvent } from 'firebase-functions/v2/scheduler';
 * import { onPubSubSchedule } from 'firebase-triggers';
 *
 * class TimerCtrl {
 *     \@onPubSubSchedule('0 5 * * *')
 *     everyDayAtFiveAM(event: ScheduledEvent) {
 *         console.log('Method executed every day at 5 AM');
 *     }
 * }
 */
export declare function onPubSubSchedule(schedule: string | ScheduleOptions): (target: any, key: string) => void;
