import { StorageOptions } from 'firebase-functions/v2/storage';
/**
 * @example
 * import { onStorageArchive } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageArchive('bucket-name')
 *     archive(event: StorageEvent) {
 *         console.log(`File ${event.data.name} archived`);
 *     }
 * }
 */
export declare const onStorageArchive: (bucket: string | StorageOptions) => (target: any, key: string) => void;
/**
 * @example
 * import { onStorageDelete } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageDelete('bucket-name')
 *     del(event: StorageEvent) {
 *         console.log(`File ${event.data.name} deleted`);
 *     }
 * }
 */
export declare const onStorageDelete: (bucket: string | StorageOptions) => (target: any, key: string) => void;
/**
 * @example
 * import { onStorageFinalize } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageFinalize('bucket-name')
 *     uploaded(event: StorageEvent) {
 *         console.log(`File ${event.data.name} uploaded`);
 *     }
 * }
 */
export declare const onStorageFinalize: (bucket: string | StorageOptions) => (target: any, key: string) => void;
/**
 * @example
 * import { onStorageMetadataUpdate } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageMetadataUpdate('bucket-name')
 *     updateMetadata(event: StorageEvent) {
 *         console.log(`File ${event.data.name} updated`);
 *     }
 * }
 */
export declare const onStorageMetadataUpdate: (bucket: string | StorageOptions) => (target: any, key: string) => void;
