"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.onStorageMetadataUpdate = exports.onStorageFinalize = exports.onStorageDelete = exports.onStorageArchive = void 0;
const internal_methods_1 = require("../internal-methods");
const types_1 = require("../types");
function getStorageFunction(trigger, metadataKey) {
    return (bucket) => (target, key) => {
        const options = typeof bucket === 'string' ? { bucket } : bucket;
        const firebaseFunction = {
            className: (0, internal_methods_1.getClassName)(target),
            methodName: key,
            method: (0, internal_methods_1.getClassMethod)(target, key),
            trigger,
            key: options.bucket,
            options,
        };
        (0, internal_methods_1.addFirebaseFunction)(firebaseFunction);
        Reflect.defineMetadata(metadataKey, options, target, key);
    };
}
/**
 * @example
 * import { onStorageArchive } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageArchive('bucket-name')
 *     archive(event: StorageEvent) {
 *         console.log(`File ${event.data.name} archived`);
 *     }
 * }
 */
exports.onStorageArchive = getStorageFunction(types_1.FirebaseTriggerType.STORAGE_ARCHIVE, 'onStorageArchive');
/**
 * @example
 * import { onStorageDelete } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageDelete('bucket-name')
 *     del(event: StorageEvent) {
 *         console.log(`File ${event.data.name} deleted`);
 *     }
 * }
 */
exports.onStorageDelete = getStorageFunction(types_1.FirebaseTriggerType.STORAGE_DELETE, 'onStorageDelete');
/**
 * @example
 * import { onStorageFinalize } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageFinalize('bucket-name')
 *     uploaded(event: StorageEvent) {
 *         console.log(`File ${event.data.name} uploaded`);
 *     }
 * }
 */
exports.onStorageFinalize = getStorageFunction(types_1.FirebaseTriggerType.STORAGE_FINALIZE, 'onStorageFinalize');
/**
 * @example
 * import { onStorageMetadataUpdate } from 'firebase-triggers';
 * import { StorageEvent } from 'firebase-functions/v2/storage';
 *
 * class TodoCtrl {
 *     \@onStorageMetadataUpdate('bucket-name')
 *     updateMetadata(event: StorageEvent) {
 *         console.log(`File ${event.data.name} updated`);
 *     }
 * }
 */
exports.onStorageMetadataUpdate = getStorageFunction(types_1.FirebaseTriggerType.STORAGE_METADATA_UPDATE, 'onStorageMetadataUpdate');
//# sourceMappingURL=storage.js.map