"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.requestErrorHandler = requestErrorHandler;
const firebase_functions_1 = require("firebase-functions");
const errors_1 = require("../errors");
/**
 * Returns method that, when executing the method passed as a parameter, makes a
 * "try catch" treatment to correctly respond to unexpected HTTP request errors.
 * @param requestHandler HTTP request method that will be executed
 */
function requestErrorHandler(requestHandler) {
    return async function (...args) {
        const res = args[1];
        try {
            requestHandler.apply(this, args);
        }
        catch (error) {
            res.status(error.responseCode || 500).json({
                success: false,
                error: (0, errors_1.mergeError)(errors_1.INTERNAL_ERROR, { error }),
            });
            firebase_functions_1.logger.error(error);
        }
    };
}
//# sourceMappingURL=request-error-handler.js.map