"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.requestSchemaValidatorHandler = requestSchemaValidatorHandler;
const ajv_1 = require("ajv");
const fs_1 = require("fs");
const errors_1 = require("../errors");
function validateRequest(req, res, schemaFile) {
    if (!schemaFile) {
        return true;
    }
    if (req.path.toLowerCase() === '/schema.json') {
        res.sendFile(schemaFile);
        return false;
    }
    const schemaString = (0, fs_1.readFileSync)(schemaFile).toString('utf8');
    const schema = JSON.parse(schemaString);
    const ajv = new ajv_1.default({ allErrors: true });
    const validate = ajv.compile(schema);
    const valid = validate(req.body);
    if (!valid) {
        const responseData = {
            success: false,
            error: errors_1.SCHEMA_INVALID,
            validations: validate.errors,
        };
        res.status(400).json(responseData);
    }
    return !!valid;
}
/**
 * Returns method that validates the request schema and responds with an error if it is not correct.
 * @param requestHandler HTTP request method that will be executed if the schema is valid
 * @param schemaFile Schema file
 */
function requestSchemaValidatorHandler(requestHandler, schemaFile) {
    return async function (...args) {
        if (validateRequest(args[0], args[1], schemaFile)) {
            return requestHandler.apply(this, args);
        }
    };
}
//# sourceMappingURL=request-schema-validator-handler.js.map