"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getFirebaseFunctionList = getFirebaseFunctionList;
exports.getClassName = getClassName;
exports.getGroupName = getGroupName;
exports.getClassMethod = getClassMethod;
exports.addFirebaseFunction = addFirebaseFunction;
const types_1 = require("./types");
const tsyringe_1 = require("tsyringe");
/** List of Cloud Functions found at startup */
const firebaseFunctionList = [];
/**
 * Returns the list of Cloud Functions found at startup or added later
 */
function getFirebaseFunctionList() {
    return firebaseFunctionList;
}
/**
 * Returns the class name of the target object
 * @param target
 */
function getClassName(target) {
    return target.constructor.name === 'Function' ? target.name : target.constructor.name;
}
/**
 * Returns group name based on class name ignoring any suffix equal to 'Ctrl'.
 * If the function's trigger is for HTTP requests and the parameter with the method name
 * is informed, then the naming rule will be ignored and the method should return undefined.
 * @param func Firebase function data
 */
function getGroupName(func) {
    const { trigger, key, className } = func;
    if (trigger === types_1.FirebaseTriggerType.HTTP_REQUEST && key) {
        const path = typeof key === 'string' ? key : key.path;
        if (path) {
            return;
        }
    }
    return className.charAt(0).toLowerCase() + className.slice(1, getSliceEnd(className));
}
/**
 * Returns the position to slice the class name, ignoring some key words
 * @param className Class name
 */
function getSliceEnd(className) {
    const suffixToRemove = ['ctrl', 'controller'];
    for (const suffix of suffixToRemove) {
        if (className.toLowerCase().endsWith(suffix))
            return -suffix.length;
    }
    return className.length;
}
/**
 * Returns the class method instantiated by the resolver to do the dependency injection.
 * @param target Control class
 * @param methodName Method name
 */
function getClassMethod(target, methodName) {
    return (...args) => {
        const instance = tsyringe_1.container.resolve(target.constructor);
        return instance[methodName](...args);
    };
}
/**
 * Adds Firebase function to the project list in memory
 * @param firebaseFunction Firebase function data
 */
function addFirebaseFunction(firebaseFunction) {
    firebaseFunctionList.push(firebaseFunction);
}
//# sourceMappingURL=internal-methods.js.map